@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 159 $
+# Revision: $Rev: 180 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -151,6 +151,11 @@ class RecordList(RecordListBase):
         self.image.saveAsPicture()
     
 
+    def changeNumber(self, mode, number):
+        """rebuild list view titles"""
+        self.listViewRecord.changeNumber(mode, number)
+        
+
     #-- slots ------------------------------------------------------------------
     def onGroup(self, group):
         """called when an online re-grouping is necessary"""
