@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 153 $
+# Revision: $Rev: 176 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -27,15 +27,15 @@ import os
 
 from copy import deepcopy
 from os.path import join as fjoin, exists as fexists
-from pprint import pformat
-
+from pprint import pformat, pprint
+from types import DictType, ModuleType
 
 
 #-- defaults -------------------------------------------------------------------
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 153 $
+# Revision: $Rev: 176 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -382,6 +382,7 @@ class _Settings0(dict):
                      'AMCFile33'             : logging.DEBUG,
                      'AMCForm'               : logging.INFO,
                      'CatalogueProperties'   : logging.DEBUG,
+                     'ChangeNumberDialog'    : logging.DEBUG,
                      'DragObject'            : logging.DEBUG,
                      'FindDialog'            : logging.DEBUG,
                      'Interface'             : logging.DEBUG,
@@ -501,6 +502,11 @@ class _Settings0(dict):
                    (u"download big picture from filmposter-archiv.de",
                     [('filmposterarchiv-de.pl', 'picture')]
                     ),
+                   
+                   'Culturalia':
+                   (u'download fields from www.culturalianet.com (spanish)',
+                    [('culturalia-es.pl', 'originalTitle', 'year', 'picture', 'category', 'actors', 'url', 'country', 'description', 'translatedTitle', 'producer', 'director'),]
+                    ),
                    },
         
         'defaultScript': '[Merkosh Special]',       
@@ -559,15 +565,34 @@ class _Settings(_Settings0):
         """returns settings object object"""
         # run parent constructor
         super(_Settings, self).__init__()
-            
-        # runtime variables
-        self.userdir = fjoin(os.environ['HOME'], '.lmc')
-        self.configFile = fjoin(self.userdir, "lmc.conf")
-        
+
+        # create logging
         self.log = logging.getLogger(self.__class__.__name__)
         self.log.setLevel(self['logLevel']['Settings'])
 
+        # runtime variables
+        self.userdir = fjoin(os.environ['HOME'], '.lmc')
+        self.configFile = fjoin(self.userdir, "lmc.conf")
+        self.updateStack = []
+        
 
+    def selfUpdate(self, toDict, fromDict):
+        """recursively updates toDict from fromDict"""
+        # toDict is initially <self> == default config settings
+        # fromDict contains all configurations from the user config file
+
+        # update all available fields from fromDict
+        for k in fromDict.keys():
+            # if both source and destination types are dicts: traverse
+            if ((type(fromDict[k]) is DictType) and (type(toDict[k]) is DictType)):
+                # recurse
+                self.selfUpdate(toDict[k], fromDict[k])
+
+            # if value is no dictionary: use value from config file
+            elif (not type(fromDict[k]) is ModuleType):
+                toDict[k] = fromDict[k]
+
+        
     def save(self):
         """saves the current version of user settings"""
         # target folder does not exist: create
@@ -606,7 +631,7 @@ class _Settings(_Settings0):
             return
 
         # add missing from default
-        self.update(config)
+        self.selfUpdate(self, config)
         
 
 
