@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 160 $
+# Revision: $Rev: 186 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -49,14 +49,14 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 160 $ (c) by Uwe Mayer")
+log.info("lmc.py - Moviefly  $Rev: 186 $ (c) by Uwe Mayer")
 
 
 #-- own imports --
 import Settings
 import MediaInfo
 
-from defaults import scriptdir
+from defaults import scriptdir, version
 
 from LMCWidgetBase import LMCWidgetBase
 from AMCFile33 import AMCFile33, AMCRecord33
@@ -69,7 +69,7 @@ from ScriptSelection import ScriptSelection
 from StdIOProcess import StdIOProcess
 from FindDialog import FindDialog
 from CatalogueProperties import CatalogueProperties
-
+from ChangeNumberDialog import ChangeNumberDialog
 
 
 # load settings
@@ -118,7 +118,7 @@ MAX_COUNT_RECENT_FILES = 4
 
 
 #-- utility functions ----------------------------------------------------------
-defaultCaption = "Moviefly ($Rev: 160 $)"
+defaultCaption = "Moviefly  v%s"%version
 filenameCaption = lambda a: defaultCaption+" - %s"%basename(a)
 
 
@@ -188,7 +188,10 @@ class LMCMain(LMCWidgetBase):
         self.modified = False           # modified metadata or deleted record
         self.recordActionsEnabled = False
         self.pictureActionsEnabled = False
-        
+
+        # set default caption
+        self.setCaption(defaultCaption)
+
         # assign slots
         self.connect(self.fileOpenAction, SIGNAL("activated()"), self.fileOpen)
         self.fileOpenAction.setEnabled(True)
@@ -574,8 +577,8 @@ class LMCMain(LMCWidgetBase):
         index = 1
         indexList.sort()
         for i in indexList:
-            if (i == index):
-                index += 1
+            if (i < index): continue
+            elif (i == index): index += 1
             else: break
 
         # append empty record
@@ -903,6 +906,19 @@ class LMCMain(LMCWidgetBase):
         self.centralWidget().onGroup(groupId)
         
 
+    def movieChangeNumber(self):
+        """called when the number of a record is to be changed"""
+        # display change number dialog
+        dlg = ChangeNumberDialog(modal=True)
+        if (dlg.exec_loop() == dlg.Rejected):
+            return
+
+        # get result
+        mode = dlg.getState()
+        number = dlg.getNumber()
+        # change number
+        self.centralWidget().changeNumber(mode, number)
+        
 
     #-- helper methods ---------------------------------------------------------
     def _updateRecentFiles(self):
@@ -1100,6 +1116,9 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolCopyAction, SIGNAL("pressed()"), self.movieCopy)
         self.toolCopyAction.setEnabled(True)
 
+        self.connect(self.movieChangeNumberAction, SIGNAL("activated()"), self.movieChangeNumber)
+        self.movieChangeNumberAction.setEnabled(True)
+        
         self.recordActionsEnabled = True
         
 
@@ -1142,6 +1161,9 @@ class LMCMain(LMCWidgetBase):
         self.toolCopyAction.setEnabled(False)
         self.disconnect(self.toolCopyAction, SIGNAL("pressed()"), self.movieCopy)
 
+        self.movieChangeNumberAction.setEnabled(False)
+        self.disconnect(self.movieChangeNumberAction, SIGNAL("activated()"), self.movieChangeNumber)
+        
         self.recordActionsEnabled = False
 
 
@@ -1189,12 +1211,22 @@ if (('-h' in app.argv()[1:]) or ('--help' in app.argv()[1:])):
 Synopsis: lmc.py [-h|--help] [<input-file>]
 
    -h       --help       this screen
+   -v       --version    show version and revision number and exit
    <input-file>          open this file on startup
                          This option overwrites the default startup file from the
                          program configuration.
 """
     sys.exit()
 
+# version
+elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
+    print "Moviefly  (c) by Uwe Mayer"
+    print "Version:  %s"%version
+    print "Revision: $Rev: 186 $"
+    print 
+    sys.exit()
+    
+
 # input file
 infile = None
 if (len(app.argv()) > 1):
